/**
 * > File for logging out smsession when SDC session idles out
 *
 * _We use a UMD structure for this script, to be able to be loaded with require js (AMD) or CommonJS/NodeJS or globally_
 *
 * @see     menujs/js/app/src/logout/logout.js
 * @name    idle_logout_smsession.js
 * @author  Alexander Vassbotn Røyne-Helgesen <alexander.royne-helgesen@bekk.no>
 * @link    https://github.com/umdjs/umd
 * @link    http://coop.stb.intra/confluence/display/KUNDEFLATE/SDC+loader
 * @link    http://coop.stb.intra/confluence/display/KUNDEFLATE/Idle+logout+smsession
 */
(function (root, factory) {

  if (typeof define === 'function' && define.amd) {

    define([
      'jquery'
    ], factory);

  } else if (typeof exports === 'object') {

    module.exports = factory(
      require('jquery')
    );

  } else {

    factory(
      root.jQuery
    );

  }

}(this, function ( $ ) {

  /**
   * Fail safe logout URL
   *
   * @type    String
   * @private
   */
  var _fail_safe_logout_url         = 'https://id.storebrand.no/auth/realms/storebrand/protocol/openid-connect/logout?post_logout_redirect_uri=https%3A%2F%2Fwww.storebrand.no%2Finfosider%2Futlogget-nettbank',
  /**
   * STB API logout url
   *
   * @type    String
   * @private
   */
  _stb_api_logout_url           = '/api/open/session/logout';

  if(sessionStorage){

    sessionStorage.clear();

  }

  $.get( _stb_api_logout_url );

  $('<img/>')
    .attr( 'src', _fail_safe_logout_url )
    .css({
      'display' : 'none'
    });

  try{

    setTimeout(function _testForCookie(){

      if(!window.cookie_handler || !window.tempvar_handler){

        _testForCookie();

      } else {

        /**
         * temp holder for smsession
         *
         * @type  String
         */
        var _smsession_cookie = window.cookie_handler('SMSESSION');


        // Clean up max counter cache
        /**
         * This is a bit ugly, and the outcome of this is, that if
         * a user hits this page, he can increase the max timer indefinetly
         */
        window.tempvar_handler( 'keepalive:user_session_started', null );
        window.tempvar_handler( 'keepalive:user_session_started:readable', null );

        // Clean up!
        window.cookie_handler( 'bank-kunde', null );
        window.tempvar_handler( 'age', null );
        window.tempvar_handler( 'LtpaToken', null );
        window.tempvar_handler( 'lang', null );
        window.tempvar_handler( 'canUseSessionStorage', null );

      }

    },1000);

  } catch(err){

    var delete_cookie = function(name) {

      document.cookie = name + '=;path=/;domain=.storebrand.no;expires=Thu, 01 Jan 1970 00:00:01 GMT;';

    };

    // Clean up max counter cache
    /**
     * This is a bit ugly, and the outcome of this is, that if
     * a user hits this page, he can increase the max timer indefinetly
     */
    delete_cookie( 'keepalive:user_session_started' );
    delete_cookie( 'keepalive:user_session_started:readable' );

    // Clean up!
    delete_cookie( 'bank-kunde' );
    delete_cookie( 'age' );
    delete_cookie( 'LtpaToken' );
    delete_cookie( 'lang' );
    delete_cookie( 'canUseSessionStorage' );



  }

}));
